Class: SubskribeDevClient::DefaultApi

Inherits:
Object
  • Object
show all
Defined in:
lib/subskribe_dev/api/default_api.rb,
lib/subskribe_dev2/api/default_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DefaultApi



19
20
21
# File 'lib/subskribe_dev/api/default_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/subskribe_dev/api/default_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_and_apply_payment(body, opts = {}) ⇒ nil

Apply a payment on a specific invoice Apply a payment per the specified parameters.



27
28
29
30
# File 'lib/subskribe_dev/api/default_api.rb', line 27

def add_and_apply_payment(body, opts = {})
  add_and_apply_payment_with_http_info(body, opts)
  nil
end

#add_and_apply_payment_with_http_info(body, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Apply a payment on a specific invoice Apply a payment per the specified parameters.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/subskribe_dev/api/default_api.rb', line 37

def add_and_apply_payment_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DefaultApi.add_and_apply_payment ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling DefaultApi.add_and_apply_payment"
  end
  # resource path
  local_var_path = '/settlements/addAndApplyPayment'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(body)
  auth_names = ['ApiKeyAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DefaultApi#add_and_apply_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_order_document(id, opts = {}) ⇒ nil



78
79
80
81
# File 'lib/subskribe_dev/api/default_api.rb', line 78

def get_order_document(id, opts = {})
  get_order_document_with_http_info(id, opts)
  nil
end

#get_order_document_with_http_info(id, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/subskribe_dev/api/default_api.rb', line 86

def get_order_document_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DefaultApi.get_order_document ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling DefaultApi.get_order_document"
  end
  # resource path
  local_var_path = '/documentLinks/{id}'.sub('{' + 'id' + '}', id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/html', 'application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['ApiKeyAuth']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DefaultApi#get_order_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#validate_address(opts = {}) ⇒ AccountAddress

Validate an address with Anrok

Options Hash (opts):



127
128
129
130
# File 'lib/subskribe_dev/api/default_api.rb', line 127

def validate_address(opts = {})
  data, _status_code, _headers = validate_address_with_http_info(opts)
  data
end

#validate_address1(opts = {}) ⇒ AccountAddress

Validate an address with TaxJar Returns a suggested addresses if found

Options Hash (opts):



177
178
179
180
# File 'lib/subskribe_dev/api/default_api.rb', line 177

def validate_address1(opts = {})
  data, _status_code, _headers = validate_address1_with_http_info(opts)
  data
end

#validate_address1_with_http_info(opts = {}) ⇒ Array<(AccountAddress, Fixnum, Hash)>

Validate an address with TaxJar Returns a suggested addresses if found

Options Hash (opts):



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/subskribe_dev/api/default_api.rb', line 187

def validate_address1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DefaultApi.validate_address1 ...'
  end
  # resource path
  local_var_path = '/taxjar/validate'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'body'])
  auth_names = ['ApiKeyAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'AccountAddress')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DefaultApi#validate_address1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#validate_address_with_http_info(opts = {}) ⇒ Array<(AccountAddress, Fixnum, Hash)>

Validate an address with Anrok

Options Hash (opts):



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/subskribe_dev/api/default_api.rb', line 137

def validate_address_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DefaultApi.validate_address ...'
  end
  # resource path
  local_var_path = '/anrok/validate'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'body'])
  auth_names = ['ApiKeyAuth']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'AccountAddress')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DefaultApi#validate_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end